EMVRegisterDeviceRequest class
Constructors
- EMVRegisterDeviceRequest({required String merchantId, required String terminalId, required String otp})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- merchantId → String
-
final
- otp → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- terminalId → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited